pub struct KeyMaterial(pub [u8; 32]);Tuple Fields
0: [u8; 32]Implementations
Sourceimpl KeyMaterial
impl KeyMaterial
Sourcepub fn random() -> Self
pub fn random() -> Self
Generates a new instance of Self with random bytes.
Attributes
#[allow(clippy::expect_used)]- Suppresses the Clippy lint warning for using.expect().#[must_use]- Indicates that the result of this function must be used by the caller, preventing accidental omission.
Returns
A new instance of Self initialized with 32 cryptographically secure
random bytes.
Panics
This function will panic if the system fails to generate random bytes.
The panic occurs at the expect call if getrandom::fill does not succeed
in generating the random numbers.